Package: SFOCDs
Type: Package
Title: Space Filling Optimal Covariate Designs
Version: 1.2.0
Authors@R: c(person("Neethu", "RS", email = "neethurs37@gmail.com", role =c( "aut","ctb")),person("Cini","Varghese",email="cini2204@gmail.com",role=c("aut","ctb")),person("Mohd", "Harun", email = "harun.agribhu@gmail.com" , role = c( "aut","ctb")),person("Anindita", "Datta", email = "aninditaiasri@gmail.com", role =c( "aut","ctb")),person("Ashutosh","Dalal", email = "ashutosh.dalal97@gmail.com", role =c( "aut","ctb", "cre")))
Description: We have designed this package to address experimental scenarios involving multiple covariates. It focuses on construction of Optimal Covariate Designs (OCDs), checking space filling property of the developed design. The primary objective of the package is to generate OCDs using four methods viz., M array method, Juxtapose method, Orthogonal Integer Array and Hadamard method. The package also evaluates space filling properties of both the base design and OCDs using the MaxPro criterion, providing a meaningful basis for comparison. In addition, it includes tool to visualize the spread offered by the design points in the form of scatterplot, which help users to assess distribution and coverage of design points.
Maintainer: Ashutosh Dalal <ashutosh.dalal97@gmail.com>
Suggests: gtools
License: GPL (>= 2)
Encoding: UTF-8
Repository: CRAN
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-28 17:40:20 UTC; Ashutosh
Author: Neethu RS [aut, ctb],
  Cini Varghese [aut, ctb],
  Mohd Harun [aut, ctb],
  Anindita Datta [aut, ctb],
  Ashutosh Dalal [aut, ctb, cre]
Date/Publication: 2026-04-29 11:50:06 UTC
Built: R 4.6.0; ; 2026-04-29 15:57:53 UTC; unix
