# Generated by roxygen2: do not edit by hand

export(HadamardOCDs)
export(JuxtaOCDs)
export(MOCDs)
export(MaxDot)
export(Maxpro_Criterion)
export(OIAOCDs)
export(reshuffle_des)
importFrom(graphics,axis)
importFrom(utils,combn)
