% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Maxpro_Criterion.R
\name{Maxpro_Criterion}
\alias{Maxpro_Criterion}
\title{Maxpro Criterion for Treatment vs Position}
\usage{
Maxpro_Criterion(design)
}
\arguments{
\item{design}{Input a design in matrix format}
}
\value{
Maxpro criterion value for a given design
}
\description{
User input should be the original design and this function
automatically convert the design in treatment vs position 2D array and then
print the Maxpro Criterion value.
}
\examples{
library(SFOCDs)
mat<-matrix(c(
1,2,3,
2,1,4,
3,4,1,
4,3,2),nrow=4,byrow=TRUE)
Maxpro_Criterion(mat)
}
